from . import normalizer
import re

DARI_MARKER = u'\u0964'

def tokenize(sentence):
    ns = normalizer.normalize(sentence)
    
    string_punctuation = '!"#$%&\()*+,-./:;<=>?@[\\]^_`{|}~'

    punc_regex = re.compile(r'(['+string_punctuation+DARI_MARKER+'])')

    sent = punc_regex.sub(r' \1 ', ns)
    # remove extra space after sentence end
    sent = sent.strip()
    # remove more than one space to single space
    # this problem occurs when two punctuation tokens are one after another
    extra_space_pattern = r"(\s{2,})"
    extra_space_regex = re.compile(extra_space_pattern)
    sent = extra_space_regex.sub(" ", sent)

    # single comma pattern
    # https://unicode.org/charts/PDF/U0900.pdf
    single_quote_pattern = r"('\s?)([\u0900-\u097F]+)(\s?')"
    single_quote_regex = re.compile(single_quote_pattern)
    sent = single_quote_regex.sub(r'\1 \2 \3', sent)

    # double comma pattern
    double_quote_pattern = r'("\s?)([\u0900-\u097F]+)(\s?")'
    double_quote_regex = re.compile(double_quote_pattern)
    sent = double_quote_regex.sub(r'\1 \2 \3', sent)

    # numbers
    # e.g. 123आरो
    number_pattern_f = r"(\d+)([\u0900-\u097F]+)"
    number_regex = re.compile(number_pattern_f)
    sent = number_regex.sub(r'\1 \2', sent)
    # e.g. आरो123
    number_pattern_b = r"([\u0900-\u097F]+)(\d+)"
    number_regex = re.compile(number_pattern_b)
    sent = number_regex.sub(r'\1 \2', sent)
    
    return sent

def tokenize_file(input, output):
    with open(input, 'r', encoding='utf-8') as rf:
        with open(output, 'w', encoding='utf-8') as wf:
            sentences = rf.readlines()
            output_sentences = []
            for sentence in sentences:
                tokenized_sentence = tokenize(sentence)
                output_sentences.append(tokenized_sentence+'\n')
            wf.writelines(output_sentences)
    return None



# if __name__ == '__main__':
#     input_sentence = "नोंसिनि फरायसालियाव य'गा फोरोंगुरु दङ नामा?"
#     tokenize(input_sentence)


# from . import helpers
"""
Normalize characters 
"""
import re
from . import helpers

def normalize(sentence):
    sentence = sentence.strip()
    # Normalize sentence

    # Turn single quotes variation to sqv1|sqv2|sqv3..|sqvn
    single_quotes_regex = re.compile('|'.join(helpers.SINGLE_QUOTE))
    # Substitute variation with '
    sentence = re.sub(single_quotes_regex, "'", sentence)
    # Turn double quotes variation to dqv1|dgv2..|dgvn
    double_quotes_regex = re.compile('|'.join(helpers.DOUBLE_QUOTE))
    # Substitute variation with "
    sentence = re.sub(double_quotes_regex, '"', sentence)

    dari_quotes_regex = re.compile('|'.join(helpers.DARI_VARIATIONS))

    # print(dari_quotes_regex)
    # unicode value of । = \u0964
    # source https://www.fileformat.info/info/unicode/char/0964/index.htm
    sentence = re.sub(dari_quotes_regex, "\u0964", sentence)
    return sentence
    print(sentence)


from setuptools import setup, find_packages

with open('README.md', encoding="utf-8") as f:
    readme = f.read()

with open('LICENSE', encoding="utf-8") as f:
    license = f.read()

setup(
    name='bodotokenizer',
    version='0.1.0',
    description='Package for Bodo Tokenizer',
    long_description=readme,
    long_description_content_type="text/markdown",
    author='Maharaj Brahma',
    author_email='mraj.brahma@gmail.com',
    url='https://github.com/bodonlp/bodo-tokenizer',
    license=license,
    packages=find_packages(exclude=["tests", "*.tests", "*.tests.*", "tests.*"]),
    python_requires=">=3.6",
    keywords=['Bodo language', 'Bodo Tokenizer'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)